@@ -1,4 +1,5 @@
 from datetime import datetime
+from enum import Enum
 from typing import Any, List, Literal, Union, Optional
 
 from api_watchdog.result_error import ResultError
@@ -7,13 +8,19 @@ from api_watchdog.validate import validate as _validate
 
 from pydantic import BaseModel, StrictStr, AnyUrl
 
+class ExpectationLevel(Enum):
+    CRITICAL = "critical"
+    WARNING = "warning"
+    INFO = "info"
+
 class Expectation(BaseModel):
     selector: StrictStr
     value: Any
     validation_type: ValidationType
+    level: ExpectationLevel = ExpectationLevel.CRITICAL
 
-    def __init__(self, selector, value, validation_type):
-        super().__init__(selector=selector, value=value, validation_type=validation_type)
+    def __init__(self, selector, value, validation_type, level=ExpectationLevel.CRITICAL):
+        super().__init__(selector=selector, value=value, validation_type=validation_type, level=level)
         self.value = _validate(self.value, self.validation_type)
 
 
