@@ -1,7 +1,7 @@
 import concurrent.futures
 import json
 import time
-from typing import Iterable, Iterator, Any, Optional, List
+from typing import Iterable, Iterator, Any
 import urllib.request
 import urllib.error
 
@@ -12,6 +12,7 @@ from api_watchdog.core import (
     WatchdogResult,
     Expectation,
     ExpectationResult,
+    ExpectationLevel,
 )
 from api_watchdog.result_error import ResultError
 from api_watchdog.validate import validate, ValidationError
@@ -70,7 +71,7 @@ class WatchdogRunner:
                 email_to=test.email_to,
                 payload=test.payload,
                 response=None,
-                results=expectation_results
+                results=expectation_results,
             )
 
         assert response is not None
@@ -84,15 +85,26 @@ class WatchdogRunner:
         expectation_results = []
         for expectation in test.expectations:
             try:
-                for e in jq.compile(expectation.selector).input(response_parsed):
+                for e in jq.compile(expectation.selector).input(
+                    response_parsed
+                ):
                     expectation_error = self.resolve_expectation(expectation, e)
                     expectation_results.append(expectation_error)
             except ValueError:
                 # jq internal error
-                expectation_results.append(ExpectationResult(expectation=expectation, result="jq-error", actual=None))
-
-        success = all([x.result == "success" for x in expectation_results])
+                expectation_results.append(
+                    ExpectationResult(
+                        expectation=expectation, result="jq-error", actual=None
+                    )
+                )
 
+        success = all(
+            [
+                (x.result == "success" and x.expectation.level == ExpectationLevel.CRITICAL)
+                or (x.expectation.level != ExpectationLevel.CRITICAL)
+                for x in expectation_results
+            ]
+        )
 
         result = WatchdogResult(
             test_name=test.name,
@@ -135,4 +147,3 @@ class WatchdogRunner:
             return ExpectationResult(
                 expectation=expectation, result="value", actual=validated_elem
             )
-
